package demo.tablecellrenderer;

import java.awt.Color;
import java.awt.Component;
import java.awt.Graphics;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.Random;

import javax.swing.Icon;
import javax.swing.ImageIcon;
import javax.swing.table.AbstractTableModel;

@SuppressWarnings("serial")
public class DemoTableModel extends AbstractTableModel
{
  private Class<?>[] columns = new Class<?>[] {String.class, Boolean.class, Byte.class, Float.class, Double.class, String.class, Date.class, Color.class, ImageIcon.class};
  private int rows;
  private int cols = columns.length;
  private ArrayList<Object[]> data;

  public DemoTableModel(int rows)
  {
    this.rows = rows;
    this.data = new ArrayList<Object[]>();
    for (int i = 0; i < rows; i++)
    {
      Object[] row = new Object[this.cols];
      this.data.add(row);
      row[0] = "cell " + i + ":" + 0;
      row[1] = new Boolean(i % 2 == 0);
      row[2] = new Byte((byte) i);
      row[3] = new Float(i / 10f);
      row[4] = new Double(i / 100d);
      row[5] = "cell " + i + ":" + 6;
      
      Calendar cal = Calendar.getInstance();
      cal.set(i+2000, i+1, i+1);
      row[6] = cal.getTime();

      int red = (i*23/1) % 255;
      int green = (i*23/2) % 255;
      int blue = (i*23/3) % 255;
      row[7] = new Color(red, green, blue);

      row[8] = createIcon();
    }
  }

  private Icon createIcon()
  {
    return new Icon()
    {
      private Color color = new Color(new Random().nextInt(0xFFFFFF));

      public int getIconHeight()
      {
        return 16;
      }

      public int getIconWidth()
      {
        return 16;
      }

      public void paintIcon(Component c, Graphics g, int x, int y)
      {
        g.setColor(color);
        g.fillRect(x, y, getIconWidth(), getIconHeight());
      }
    };
  }

  @Override
  public Class<?> getColumnClass(int columnIndex)
  {
    return this.columns[columnIndex];
    //return Object.class;
  }

  public int getColumnCount()
  {
    return cols;
  }

  public int getRowCount()
  {
    return rows;
  }

  public Object getValueAt(int row, int col)
  {
    return data.get(row)[col];
  }

  @Override
  public String getColumnName(int column)
  {
    return getColumnClass(column).getSimpleName();
  }

  @Override
  public boolean isCellEditable(int rowIndex, int columnIndex)
  {
    return (rowIndex % 2 == 0);
  }

  @Override
  public void setValueAt(Object value, int row, int col)
  {
    data.get(row)[col] = value;
    fireTableCellUpdated(row, col);
  }

  public void deleteRows(int startIndex, int count)
  {
    int index = startIndex + count - 1;
    while (index >= startIndex)
    {
      data.remove(index);
      index--;
    }
    fireTableRowsDeleted(startIndex, startIndex + count - 1);
  }
}
