package demo.tablecellrenderer.renderer;

import java.awt.Color;
import java.awt.Component;

import javax.swing.JTable;
import javax.swing.UIManager;
import javax.swing.table.TableCellRenderer;

public class ColumnRowBackgroundRenderer implements TableCellRenderer
{
  private TableCellRenderer delegate;
  private Color alternateColor; 

  public ColumnRowBackgroundRenderer(TableCellRenderer defaultRenderer)
  {
    this.delegate = defaultRenderer;
    alternateColor = UIManager.getColor("Table.alternateRowColor");
  }

  public Component getTableCellRendererComponent(JTable table, Object value, 
                           boolean isSelected, boolean hasFocus, int row, int column) 
  {
    Component c = delegate.getTableCellRendererComponent(table, value, isSelected, 
                                                                hasFocus, row, column);      
    if (!isSelected)
    {  
      int modelColumn = table.convertColumnIndexToModel(column);
      //because of the color caching we have to reset the background to table background
      //if color caching is disabled you can also use c.getBackground instead of table.getBackground
      //for resetting background respect alternating row background
      Color defaultBackground = (row % 2 == 0 && alternateColor != null) ? alternateColor : table.getBackground();
      //be careful with background colors - if your background color is very different from
      //the default background it's recommended to also modify the foreground color for being 
      //theme independent (dark themes often use bright foreground colors)
      c.setBackground(modelColumn == 5 ? new Color(0xFFF0E0) : defaultBackground);
      c.setBackground(row == 2 ? new Color(0xDDD7FF) : c.getBackground());
    }
    return c;
  }
}